Revert "Revert adoption of CUDA indexing in general - this can only work with later versions of the compiler, just like module based dispatch, and thus must be guarded against usage in earlier (e.g. 1.6) versions."

This reverts commit d2fd1f5
This commit is contained in:
Alex Voicu
2017-11-29 21:49:10 +00:00
parent 7acb1e6ff6
commit 32e11e7dc6
63 changed files with 171 additions and 173 deletions
+2 -2
View File
@@ -16,13 +16,13 @@
__global__ void cpy(hipLaunchParm lp, uint32_t *Out, uint32_t *In)
{
int tx = hipThreadIdx_x;
int tx = threadIdx.x;
memcpy(Out + tx, In + tx, sizeof(uint32_t));
}
__global__ void set(hipLaunchParm lp, uint32_t *ptr, uint8_t val, size_t size)
{
int tx = hipThreadIdx_x;
int tx = threadIdx.x;
memset(ptr + tx, val, sizeof(uint32_t));
}